==> jakarta-faces-tck-4.0.4.zip: faces-tck-4.0.4/tck/faces23/cdi/src/test/java/ee/jakarta/tck/faces/test/javaee8/cdi/Spec1418IT.java <==
/*
 * Copyright (c) 1997, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package ee.jakarta.tck.faces.test.javaee8.cdi;

import static java.lang.System.getProperty;
import static org.jboss.shrinkwrap.api.ShrinkWrap.create;
import static org.junit.Assert.assertTrue;

import java.io.File;
import java.net.URL;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.arquillian.test.api.ArquillianResource;
import org.jboss.shrinkwrap.api.importer.ZipImporter;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import com.gargoylesoftware.htmlunit.WebClient;
import com.gargoylesoftware.htmlunit.html.HtmlPage;

import jakarta.faces.annotation.ManagedProperty;
import jakarta.inject.Inject;

/**
 * Tests the injection of values by {@link ManagedProperty}
 *
 */
@RunWith(Arquillian.class)
public class Spec1418IT {

    @ArquillianResource
    private URL webUrl;
    private WebClient webClient;

    @Deployment(testable = false)
    public static WebArchive createDeployment() {
        return create(ZipImporter.class, getProperty("finalName") + ".war")
                .importFrom(new File("target/" + getProperty("finalName") + ".war"))
                .as(WebArchive.class);
    }

    @Before
    public void setUp() {
        webClient = new WebClient();
    }

    @After
    public void tearDown() {
        webClient.close();
    }

    /**
     * @see Inject
     * @see ManagedProperty
     * @see https://github.com/jakartaee/faces/issues/1418
     */
    @Test
    public void testManagedPropertyInteger() throws Exception {
        HtmlPage page = webClient.getPage(webUrl + "injectManagedProperty.xhtml");

        assertTrue(page.asXml().contains("integer1:42"));
        assertTrue(page.asXml().contains("integer2:99"));
        assertTrue(page.asXml().contains("integer3:123"));
    }

    /**
     * @see Inject
     * @see ManagedProperty
     * @see https://github.com/jakartaee/faces/issues/1418
     */
    @Test
    public void testManagedPropertyString() throws Exception {
        HtmlPage page = webClient.getPage(webUrl + "injectManagedProperty.xhtml?test=foo");

        assertTrue(page.asXml().contains("testParam:foo"));
    }

    /**
     * @see Inject
     * @see ManagedProperty
     * @see https://github.com/jakartaee/faces/issues/1418
     */
    @Test
    public void testManagedPropertyGenericMap() throws Exception {
        HtmlPage page = webClient.getPage(webUrl + "injectManagedProperty.xhtml");

        assertTrue(page.asXml().contains("stringMap:bar"));
        assertTrue(page.asXml().contains("integerMap:10"));
    }

}

==> jakarta-faces-tck-4.1.2.zip: faces-tck-4.1.2/tck/faces23/cdi/src/test/java/ee/jakarta/tck/faces/test/javaee8/cdi/Spec1418IT.java <==
/*
 * Copyright (c) 1997, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package ee.jakarta.tck.faces.test.javaee8.cdi;

import static java.lang.System.getProperty;
import static org.jboss.shrinkwrap.api.ShrinkWrap.create;
import static org.junit.Assert.assertTrue;

import java.io.File;
import java.net.URL;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.arquillian.test.api.ArquillianResource;
import org.jboss.shrinkwrap.api.importer.ZipImporter;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import org.htmlunit.WebClient;
import org.htmlunit.html.HtmlPage;

import jakarta.faces.annotation.ManagedProperty;
import jakarta.inject.Inject;

/**
 * Tests the injection of values by {@link ManagedProperty}
 *
 */
@RunWith(Arquillian.class)
public class Spec1418IT {

    @ArquillianResource
    private URL webUrl;
    private WebClient webClient;

    @Deployment(testable = false)
    public static WebArchive createDeployment() {
        return create(ZipImporter.class, getProperty("finalName") + ".war")
                .importFrom(new File("target/" + getProperty("finalName") + ".war"))
                .as(WebArchive.class);
    }

    @Before
    public void setUp() {
        webClient = new WebClient();
    }

    @After
    public void tearDown() {
        webClient.close();
    }

    /**
     * @see Inject
     * @see ManagedProperty
     * @see https://github.com/jakartaee/faces/issues/1418
     */
    @Test
    public void testManagedPropertyInteger() throws Exception {
        HtmlPage page = webClient.getPage(webUrl + "injectManagedProperty.xhtml");

        assertTrue(page.asXml().contains("integer1:42"));
        assertTrue(page.asXml().contains("integer2:99"));
        assertTrue(page.asXml().contains("integer3:123"));
    }

    /**
     * @see Inject
     * @see ManagedProperty
     * @see https://github.com/jakartaee/faces/issues/1418
     */
    @Test
    public void testManagedPropertyString() throws Exception {
        HtmlPage page = webClient.getPage(webUrl + "injectManagedProperty.xhtml?test=foo");

        assertTrue(page.asXml().contains("testParam:foo"));
    }

    /**
     * @see Inject
     * @see ManagedProperty
     * @see https://github.com/jakartaee/faces/issues/1418
     */
    @Test
    public void testManagedPropertyGenericMap() throws Exception {
        HtmlPage page = webClient.getPage(webUrl + "injectManagedProperty.xhtml");

        assertTrue(page.asXml().contains("stringMap:bar"));
        assertTrue(page.asXml().contains("integerMap:10"));
    }

}
